paulicirc.builders
==================

.. automodule:: paulicirc.builders

CircuitBuilder
--------------

.. autoclass:: paulicirc.builders.CircuitBuilder
    :show-inheritance:
    :members:
    :special-members: __new__
